package com.pfc.Actividades.RealidadAumentada;

import java.util.List;
import android.content.Context;
import android.hardware.Sensor;
import android.hardware.SensorEvent;
import android.hardware.SensorEventListener;
import android.hardware.SensorManager;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;

import com.pfc.Utilidades.ControladorBrujula;


public class GestorBrujula implements SensorEventListener{
	
	OnCompassChangeListener onCompassChangeListener = null;
	private SensorManager sm;
	
    private float[] acc_values = new float[3];
    private float[] mag_values = new float[3];
    private float correction;
    private ControladorBrujula azimuthPID = new ControladorBrujula(0.8f, true);
    private ControladorBrujula elevationPID = new ControladorBrujula(0.5f, false);
	
	public GestorBrujula(Context mContext){
		
		sm = (SensorManager) mContext.getSystemService(Context.SENSOR_SERVICE);
		correction = 0;
	}
	
    public static float getAzimuth(float[] values){
    	return values[0];
    }
    
    public static float getElevation(float[] values){
    	return values[1];
    }
    
	
    private void setSensors(){
    	//Setting a sensor listener for accelerometer and magnetic field sensors
    	
    	try {
    		List<Sensor> sensors = sm.getSensorList(Sensor.TYPE_ACCELEROMETER);
//    		
//    		if(sensors.size()>0){
//    			Sensor sensor = sensors.get(0);
//    			sm.registerListener(this, sensor, SensorManager.SENSOR_DELAY_NORMAL);
//    		}
    		if(sensors.size()>0){
    			Sensor sensor = sensors.get(0);
    			sm.registerListener(this, sensor, SensorManager.SENSOR_DELAY_NORMAL);
    		}
    		
    		sensors = sm.getSensorList(Sensor.TYPE_MAGNETIC_FIELD);
    		
    		if(sensors.size()>0){
    			Sensor sensor = sensors.get(0);
    			sm.registerListener(this, sensor, SensorManager.SENSOR_DELAY_NORMAL);
    		}
			
		} catch (Exception e) {
			Log.e("GestorBrujula", "", e);
		}
    }
    
    public void setOnCompassChangeListener(OnCompassChangeListener onCompassChangeListener){
    	if (this.onCompassChangeListener == null)
    		setSensors();
    	this.onCompassChangeListener = onCompassChangeListener;
    }
    
    public void unregisterListeners(){
    	sm.unregisterListener(this);
    	onCompassChangeListener = null;
    }
    
    private void OnCompassMeasure(){
    	if(onCompassChangeListener == null)
    		return;
    	
    	float[] values = new float[3];
    	float[] inr = new float[9];
    	float[] outr = new float[9];
    	float[] i = new float[9];
    	
    	float[] values_acc = acc_values.clone();
    	float[] values_mag = mag_values.clone();
    	
    	SensorManager.getRotationMatrix(inr, i, values_acc, values_mag);
    	
    	if(inr==null)
    		return;
    	
    	SensorManager.remapCoordinateSystem(inr, SensorManager.AXIS_X, SensorManager.AXIS_Z, outr);
    	
    	SensorManager.getOrientation(outr, values);
    	values[0] = (float) Math.toDegrees(values[0]);
    	values[1] = (float) Math.toDegrees(values[1]);
    	values[2] = (float) Math.toDegrees(values[2]);
    	
    	// correction of the measures
    	//azimuth
    	values[0] += correction;
    	if(values[0] < 0)
    		values[0] += 360;
		//elevation
    	values[1] = 90 - values[1];
    	values[0] = azimuthPID.getValue(values[0]);
    	values[1] = elevationPID.getValue(values[1]);
    	
    	onCompassChangeListener.onChange(values);
    }
	
	public void onAccuracyChanged(Sensor sensor, int accuracy) {
	}

	public void onSensorChanged(SensorEvent event) {
		switch(event.sensor.getType()){
		case Sensor.TYPE_ACCELEROMETER:
			acc_values = event.values.clone();
			break;

		case Sensor.TYPE_MAGNETIC_FIELD:
			mag_values = event.values.clone();
			OnCompassMeasure();
			break;
		}	
	}	
	
	
	public interface OnCompassChangeListener {
		public abstract void onChange(float[] values);
	}
}