package com.pfc.Actividades;

import java.util.ArrayList;
import java.util.List;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
import android.view.Gravity;
import android.view.Menu;
import android.view.MenuItem;
import android.view.SubMenu;
import android.view.View;
import android.view.ViewGroup.LayoutParams;
import android.widget.FrameLayout;

import com.pfc.Actividades.R;
import com.pfc.Actividades.Rutas.ServicioLocalizacion;
import com.google.android.maps.GeoPoint;
import com.google.android.maps.MapActivity;
import com.google.android.maps.MapController;
import com.google.android.maps.MapView;
import com.google.android.maps.Overlay;
import com.pfc.Info.GeoNodo;
import com.pfc.Superposicion.SuperposicionMapa;

// Es la actividad que se encarga de mostrar el mapa cuando picas sobre un nodo, por ej
// el puente de triana.

public class VerMapa extends MapActivity {

	   private MapView mapView; 
	   private GeoPoint point;	   
	   private String mUrl;

	   private static final int MENU_MAP = Menu.FIRST + 1;
	   private static final int MENU_MAP_SATELITE = Menu.FIRST + 2;
	   private static final int MENU_MAP_NORMAL = Menu.FIRST + 3;
	   private static final int MENU_GOTOPLACE = Menu.FIRST + 4;
	   private static final int MENU_GOTOURL = Menu.FIRST + 5;
	   
	   private Double mLatitude, mLongitude;
	   @Override
	   public void onCreate(Bundle icicle) {
		   
		   super.onCreate(icicle);
		   
		   FrameLayout frame = new FrameLayout(this);
		   
		   mapView = new MapView(this, getString(R.string.map_key));
		   MapController mapControl = mapView.getController();
		  
	       frame.addView(mapView, 
	                new FrameLayout.LayoutParams(LayoutParams.FILL_PARENT, LayoutParams.FILL_PARENT));
    
		   setContentView(frame);		  
		   
		   /* Obtain data */
		   Intent i = getIntent();

		   mLatitude  = i.getDoubleExtra("latitude", Integer.MIN_VALUE);
		   mLongitude = i.getDoubleExtra("longitude", Integer.MIN_VALUE);
		   mUrl 			= i.getStringExtra("url");

		   point = new GeoPoint((int) (mLatitude * 1000000), (int) (mLongitude * 1000000));
		   mapControl.setZoom(20);
		   mapControl.setCenter(point);
		   
		   /* Config overlay */
		   SuperposicionMapa myMapOver = new SuperposicionMapa();
		   myMapOver.setDrawable(getResources().getDrawable(R.drawable.map_pin));
		   myMapOver.setGeoPoint(point);
		    
	       final List<Overlay> overlays = mapView.getOverlays();
	       overlays.add(myMapOver);
	       
	       /* Settings map */
	       mapView.setClickable(true);
	       mapView.setEnabled(true);
	       mapView.setSatellite(false);

		   addZoomControls(frame);
	   }
	   
	   @Override
	   protected boolean isRouteDisplayed() {
	      // TODO Auto-generated method stub
	      return false;
	   }

	   
	   
	    private void addZoomControls(FrameLayout frame) {
	        View zoomControls = mapView.getZoomControls();

	        FrameLayout.LayoutParams p = 
	            new FrameLayout.LayoutParams(LayoutParams.WRAP_CONTENT,
	                LayoutParams.WRAP_CONTENT, Gravity.BOTTOM + Gravity.CENTER_HORIZONTAL);
	        frame.addView(zoomControls, p);
	    }
	    

	    
	    @Override
	    public boolean onCreateOptionsMenu(Menu menu) {
	    	
	        super.onCreateOptionsMenu(menu);
	         
	        SubMenu sub = menu.addSubMenu(0,MENU_MAP,0,"View Map");
	        
	        sub.add(0, MENU_MAP_SATELITE, 0, "Satelite View");
	        
	        sub.add(0, MENU_MAP_NORMAL, 0, "Normal View");
   
	        menu.add(0, MENU_GOTOPLACE, 0, "Go to Place")
    					.setAlphabeticShortcut('C');
	        
	        if (mUrl != "")
	        {
	        	menu.add(0, MENU_GOTOURL, 0, "Go to Url")
	        	.setAlphabeticShortcut('C');
	        }
	        
	        return true;
	    }
	    
	    @Override
	    public boolean onOptionsItemSelected (MenuItem item) {
	    	
	    	switch (item.getItemId()) {
	    	
	    	case MENU_MAP_SATELITE:
	    		mapView.setSatellite(true);
	    		break;
	    		
	    	case MENU_MAP_NORMAL:
	    		mapView.setSatellite(false);
	    		break;
	    		
	    	case MENU_GOTOURL:
	    		
	            Intent i = new Intent(Intent.ACTION_VIEW);
	            i.setData(Uri.parse(mUrl));
	            startActivity(i);

	    		break;
	        }
	        return super.onOptionsItemSelected(item);
	    }
	    
	    
	    protected void onActivityResult (int requestCode, int resultCode, Intent data) { 
	    
	    }
	}